Fixed an issue with reading in the new config files into topology_rest.py where link down/up stopped working
diff --git a/web/config.json.hw b/web/config.json.hw
index 493a2b4..533bbee 100644
--- a/web/config.json.hw
+++ b/web/config.json.hw
@@ -1,5 +1,6 @@
 {
     "LB": false, 
+    "TESTBED": "hw",
     "ONOS_DEFAULT_HOST": "localhost",
     "ONOS_GUI3_CONTROL_HOST": "http://10.128.4.11:9000", 
     "ONOS_GUI3_HOST": "http://10.128.4.11:9000", 
diff --git a/web/config.json.sw b/web/config.json.sw
index b1903c6..282e17a 100644
--- a/web/config.json.sw
+++ b/web/config.json.sw
@@ -1,5 +1,6 @@
 {
     "LB": false, 
+    "TESTBED": "sw",
     "ONOS_DEFAULT_HOST": "localhost",
     "ONOS_GUI3_CONTROL_HOST": "http://devy-gui.onlab.us:8080", 
     "ONOS_GUI3_HOST": "http://devy-gui.onlab.us:8080", 
diff --git a/web/config.json.sw_dev b/web/config.json.sw_dev
index 57a1a3d..bb89670 100644
--- a/web/config.json.sw_dev
+++ b/web/config.json.sw_dev
@@ -1,5 +1,6 @@
 {
     "LB": false, 
+    "TESTBED": "sw",
     "ONOS_DEFAULT_HOST": "localhost",
     "ONOS_GUI3_CONTROL_HOST": "http://devy-gui.onlab.us:8080", 
     "ONOS_GUI3_HOST": "http://devy-gui.onlab.us:8080", 
diff --git a/web/topology_rest.py b/web/topology_rest.py
index b1ce2ca..44d7ab7 100755
--- a/web/topology_rest.py
+++ b/web/topology_rest.py
@@ -23,12 +23,13 @@
 DEBUG=1
 
 def read_config():
   global LB, controllers, core_switches, ONOS_GUI3_HOST, ONOS_GUI3_CONTROL_HOST
   f = open(CONFIG_FILE)
   conf = json.load(f)
   LB = conf['LB']
+  TESTBED = conf['TESTBED']
   controllers = conf['controllers']
-  core_switcehs=conf['core_switches']
+  core_switches=conf['core_switches']
   ONOS_GUI3_HOST=conf['ONOS_GUI3_HOST']
   ONOS_GUI3_CONTROL_HOST=conf['ONOS_GUI3_CONTROL_HOST']
   f.close()
@@ -23,12 +23,13 @@
 
 def read_config():
-  global LB, controllers, core_switches, ONOS_GUI3_HOST, ONOS_GUI3_CONTROL_HOST
+  global LB, TESTBED, controllers, core_switches, ONOS_GUI3_HOST, ONOS_GUI3_CONTROL_HOST
   f = open(CONFIG_FILE)
   conf = json.load(f)